# ESB iRule to change the destination VIP and URI based on source URI
# https://devcentral.f5.com/articles/irules-101-04-switch
# https://devcentral.f5.com/s/question/0D51T00006i7de9SAA/http-rewrite-header-pool-based-on-uri
#
when HTTP_REQUEST {
  # Get Packet UUID info if any
  set uuid "None"
  set packet_uuid [HTTP::header values uniqueid]
  set packet_uuid_len [string length $packet_uuid]
  if { $packet_uuid_len > 0 } {
     set uuid [HTTP::header values uniqueid]
  }

  # Get and Set X-Forwarded-For Info
  set xfwd [IP::client_addr]
  set packet_sfwd [HTTP::header X-Forwarded-For]
  set packet_sfwd_len [string length $packet_sfwd]
  if { $packet_sfwd_len > 0 } {
     # If X-Forwarded-For exists Put it into a variable for logging
     set xfwd [HTTP::header X-Forwarded-For]
  } else {
     # X-Forwarded-For doesn't exist so add it to the HTTP Header
     HTTP::header insert X-Forwarded-For [IP::client_addr]
  }

  # Connection is allways HTTPS and VIP Always has serverssl enabled.
  #################--Seperate iRule for HTTP VIP!--#################


  #----------------BEGIN VIP and pools--------------#
  set legacy_hostname "gateway.napaprolink.com"
  set pool_port_1 "_pool_80"
  set vip_name_1 $legacy_hostname
  set pool_1 $vip_name_1$pool_port_1 
  #----------------END VIP and pools--------------#
  #----------------BEGIN Re-Write and Redirect--------------#
  set new_hostname_1 "esb.genpt.com"
  set new_hostname_2 "esbuat.genpt.com"
  # Dallas ESB DR VIP has odd Name Need to get with Cory Schaubs or Rebekah Beary to get it changed
  set new_vip_1 "esbatl.genpt.com_vip_443"
  set new_pool_1 "esbuat.genpt.com_pool_443_vip"
  #----------------End Re-Write and Redirect--------------#

  # Get Initial Info before modifications
  set request_host [HTTP::host]
  set request_uri [HTTP::uri]
  set LogString1 "VIP:[virtual name], HTTP_REQUEST, UUID:$uuid, Client IP:[IP::client_addr], Real Client IP $xfwd:[TCP::client_port], Requested URL $request_host$request_uri,"
  # Match the URI then re-write accordingly
  # Matches in each section below should be in Alphabetical order
  # to facilitate a structure/be identical from environment to environment
  switch -glob [HTTP::uri] {
  	"/b2bBridge/*" -
  	"/b2bBridge[?]*" -
  	"/b2bBridgeSDK*" -
	"/b2bBridgetest*" -
  	"/b2bBridge2*" -
	"/TamsService*" {
	# Alphabetical Order skipped for longest match first
    # If URI Matched then re-write the host/FQDN and possibly the URI
      HTTP::header replace Host $new_hostname_1
      HTTP::uri "/esbbridgerouter?[HTTP::query]"
      virtual $new_vip_1
      set myvip $new_vip_1
	  set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri], VIP $myvip"
    }	
    "/b2bBridge3*" {
    # If URI Matched then re-write the host/FQDN and possibly the URI
      HTTP::header replace Host $new_hostname_1
      HTTP::uri "/esbaswarouter?[HTTP::query]"
      virtual $new_vip_1
      set myvip $new_vip_1
      set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri], VIP $myvip"
    }
	"/b2bBridgeProlink*" {
	# Alphabetical Order skipped for longest match first
    # If URI Matched then re-write the host/FQDN and possibly the URI
      HTTP::header replace Host $new_hostname_1
      HTTP::uri "/esbprolinkrouter?[HTTP::query]"
      virtual $new_vip_1
      set myvip $new_vip_1
	  set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri], VIP $myvip"
    }	
    "/fastreggate2*" {
    # If URI Matched then re-write the host/FQDN and possibly the URI
      HTTP::header replace Host $new_hostname_2
      HTTP::uri "/prolinkregistration"
      virtual $new_vip_1
      set myvip $new_vip_1
	  pool $new_pool_1
      set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri], VIP $myvip"
    }
    "/fastreggate*"	{
    # If URI Matched then re-write the host/FQDN and possibly the URI
      HTTP::header replace Host $new_hostname_1
      HTTP::uri "/prolinkregistration"
      virtual $new_vip_1
      set myvip $new_vip_1
      set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri], VIP $myvip"
    }
 	"/findItGate*" {
	# Alphabetical Order skipped for longest match first
    # If URI Matched then re-write the host/FQDN and possibly the URI
      HTTP::header replace Host $new_hostname_1
      HTTP::uri "/esbfindituaprouter?[HTTP::query]"
      virtual $new_vip_1
      set myvip $new_vip_1
	  set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri], VIP $myvip"
    }
	"/multiStoreGate*" {
	# Alphabetical Order skipped for longest match first
    # If URI Matched then re-write the host/FQDN and possibly the URI
      HTTP::header replace Host $new_hostname_1
      HTTP::uri "/esbmultistoregaterouter?[HTTP::query]"
      virtual $new_vip_1
      set myvip $new_vip_1
	  set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri], VIP $myvip"
    }
    "/ISSCtest*" {
	# Alphabetical Order skipped for longest match first
    # If URI Matched then re-write the host/FQDN and possibly the URI
      HTTP::header replace Host $new_hostname_1
	  #HTTP::header replace Host $new_hostname_2 -- ONLY USE if above is not working
      HTTP::uri "/esbisscrouter"
      virtual $new_vip_1
      set myvip $new_vip_1
	  pool $new_pool_1
	  set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri], VIP $myvip"
	}
    "/ISSC*" {
	# Alphabetical Order skipped for longest match first
    # If URI Matched then re-write the host/FQDN and possibly the URI
      HTTP::header replace Host $new_hostname_1
      HTTP::uri "/esbisscrouter"
      virtual $new_vip_1
      set myvip $new_vip_1
	  set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri], VIP $myvip"
    }
	"/secureb2bBridgetest*" {
	# Alphabetical Order skipped for longest match first
    # If URI Matched then re-write the host/FQDN and possibly the URI
      HTTP::header replace Host $new_hostname_2
      HTTP::uri "/esbsecurebridgerouter?[HTTP::query]"
      virtual $new_vip_1
      set myvip $new_vip_1
	  set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri], VIP $myvip"
    }
	"/secureb2bBridge*" {
	# Alphabetical Order skipped for longest match first
    # If URI Matched then re-write the host/FQDN and possibly the URI
      HTTP::header replace Host $new_hostname_1
      HTTP::uri "/esbsecurebridgerouter?[HTTP::query]"
      virtual $new_vip_1
      set myvip $new_vip_1
	  set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri], VIP $myvip"
    }
    "/*" {
    # Default Match All for VIP - Do not re-write these matches
    # Legacy URI Disable serverssl!!!!
      SSL::disable serverside
      pool $pool_1
	  set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri]"
    }
  }
}
when LB_SELECTED {
      # Create Variable to Log Pool Member Chosen
      set LogString2 "to Pool Mbr [LB::server addr]"
      # Log Client IP, URL, and Pool Member Chosen
      log local0. "$LogString $LogString2"
}
when HTTP_RESPONSE {
  set uuid "None"
  set packet_uuid [HTTP::header values uniqueid]
  set packet_uuid_len [string length $packet_uuid]
  if { $packet_uuid_len > 0 } {
     set uuid [HTTP::header values uniqueid]
  }

  # Collect data in the Response packet_sfwd
  set reply_host [HTTP::header host]
  set reply_uri [HTTP::header uri]

  log local0. "VIP:[virtual name], HTTP_RESPONSE, UUID:$uuid, HTTP Code:[HTTP::status], Pool Member:[LB::server addr], Pool Member URL $reply_host$reply_uri, Reply URI [HTTP::header host][HTTP::header uri] , Client IP:[IP::client_addr]:[TCP::client_port]"
}