# ESB iRule to set correct pool based on URI
# https://devcentral.f5.com/articles/irules-101-04-switch
#
when HTTP_REQUEST { 
  set uuid "None"
  set packet_uuid [HTTP::header values uniqueid]
  set packet_uuid_len [string length $packet_uuid]
  if { $packet_uuid_len > 0 } {
     set uuid [HTTP::header values uniqueid]
  }
    if {[HTTP::header exists X-Forwarded-For]}{
      HTTP::header replace X-Forwarded-For "[HTTP::header X-Forwarded-For], [IP::client_addr]"
  } else {  
      HTTP::header insert X-Forwarded-For [IP::client_addr]
  }											   
  set xfwd [IP::client_addr]
  set packet_xfwd [HTTP::header X-Forwarded-For]
  set packet_xfwd_len [string length $packet_xfwd]
  if { $packet_xfwd_len > 0 } {
     set xfwd [HTTP::header X-Forwarded-For]
  }  
  #----------------BEGIN pools--------------#
  set vip_name_1 "esb2.genpt.com"
  set pool_port_1 "_pool_8081"
  set pool_port_2 "_pool_8082"
  set pool_1 $vip_name_1$pool_port_1
  set pool_2 $vip_name_1$pool_port_2
  set LogString1 "VIP:[virtual name], HTTP_REQUEST, UUID:$uuid, Client IP:[IP::client_addr], Real Client IP $xfwd:[TCP::client_port], Requested URL [HTTP::host][HTTP::uri]"
  # Matches in each section below should be in Alphabetical order
  # to facilitate a structure/be identical from environment to environment
  switch -glob [string tolower [HTTP::uri]] {
    "/pinghttpd1" { 
      # If any of the above is in the URI use the below pool
      HTTP::uri "/pinghttpd/"
	  # re-write the uri the ending number is only used to distingush between pools.
	  # It doesn't exist on the servers.  The servers will only respond to pinghttpd

      pool $pool_1
      set mypool $pool_1
      set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
    "/pinghttpd2" { 
      # If any of the above is in the URI use the below pool
      HTTP::uri "/pinghttpd/"
	  # re-write the uri the ending number is only used to distingush between pools.
	  # It doesn't exist on the servers.  The servers will only respond to pinghttpd
      pool $pool_2
      set mypool $pool_2
      set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
	"/b2bbridge/*" -
  	"/b2bbridge[?]*" -
  	"/b2bbridgesdk*" -
  	"/b2bbridgetest*" -
  	"/b2bbridge2*" -
	"/tamsservice*" {
      HTTP::uri "/esbbridgerouter?[HTTP::query]"
      pool $pool_1
      set mypool $pool_1
      set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
    "/b2bbridgeprolink*" {
      HTTP::uri "/esbprolinkrouter?[HTTP::query]"
      pool $pool_1
      set mypool $pool_1
      set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
    "/b2bbridge3*" {
      HTTP::uri "/esbaswarouter?[HTTP::query]"
      pool $pool_1
      set mypool $pool_1
      set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
    "/fastreggate2*" -
    "/fastreggate*" {
      HTTP::uri "/prolinkregistration"
      pool $pool_1
      set mypool $pool_1
      set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
    "/finditgate*" {
      HTTP::uri "/esbfindituaprouter?[HTTP::query]"
      pool $pool_1
      set mypool $pool_1
      set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
    "/multistoregate*" {
      HTTP::uri "/esbmultistoregaterouter?[HTTP::query]"
      pool $pool_1
      set mypool $pool_1
      set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
    "/secureb2bbridge*" {
      HTTP::uri "/esbsecurebridgerouter?[HTTP::query]"
      pool $pool_1
      set mypool $pool_1
      set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri], Pool $mypool"
    }    
    "/issctest*" -
    "/issc*" {
      HTTP::uri "/esbisscrouter"
      pool $pool_1
      set mypool $pool_1
      set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
    "/*" {
      # If any of the above is in the URI use the below pool
      pool $pool_1
      set mypool $pool_1
      set LogString "$LogString1 Sent URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
  }
  #----------------END pools----------------#
}
when LB_SELECTED {
      # Create Variable to Log Pool Member Chosen
      set LogString2 "to Pool Mbr [LB::server addr]"
      # Log Client IP, URL, and Pool Member Chosen
      log local0. "$LogString $LogString2"
}
when HTTP_RESPONSE {
  set uuid "None"
  set packet_uuid [HTTP::header values uniqueid]
  set packet_uuid_len [string length $packet_uuid]
  if { $packet_uuid_len > 0 } {
     set uuid [HTTP::header values uniqueid]
  }
  log local0. "VIP:[virtual name], HTTP_RESPONSE, UUID:$uuid, HTTP Code:[HTTP::status], Pool Member:[LB::server addr] Client IP:[IP::client_addr]:[TCP::client_port]"
															 
														 
	   
	
}
