# ESB iRule to set correct pool based on URI
# https://devcentral.f5.com/articles/irules-101-04-switch
#
when HTTP_REQUEST { 
  set uuid "None"
  set packet_uuid [HTTP::header values uniqueid]
  set packet_uuid_len [string length $packet_uuid]
  if { $packet_uuid_len > 0 } {
     set uuid [HTTP::header values uniqueid]
  }
  set xfwd [IP::client_addr]
  set packet_xfwd [HTTP::header X-Forwarded-For]
  set packet_xfwd_len [string length $packet_xfwd]
  if { $packet_xfwd_len > 0 } {
     set xfwd [HTTP::header X-Forwarded-For]
  }  
  #----------------BEGIN pools--------------#
  set pool_nsight_invoice "esbms2.genpt.net_pool_10000"
  set pool_nsight_customer "esbms2.genpt.net_pool_10002"
  set pool_nsight_product_availability "esbms2.genpt.net_pool_19111_19112"
  set pool_nsight_product_availability_b2b "esbms2.genpt.net_pool_19113_19114"
  set pool_maintenance "esbms2.genpt.net_pool_19999"
  set pool_triggerssh "esbms2.genpt.net_pool_19115"
  set LogString1 "VIP:[virtual name], HTTP_REQUEST, UUID:$uuid, Client IP:[IP::client_addr], Real Client IP $xfwd:[TCP::client_port], Requested URL [HTTP::host][HTTP::uri], Pool "
  # Matches in each section below should be in Alphabetical order
  # to facilitate a structure/be identical from environment to environment
  switch -glob [string tolower [HTTP::uri]] {
    "/health-nsight-invoice" -
    "/invoice/inquiry/v1*" -
    "/invoice/invoicemessage*" -
    "/invoice/storenum*" -
    "/v1/invoice*" -
    "/v2/invoice*" {
      if {[string tolower [HTTP::uri]] == "/health-nsight-invoice" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_nsight_invoice
      set mypool $pool_nsight_invoice
      set LogString "$LogString1 $mypool"
    }
    "/customer*" -
    "/health-nsight-customer" {
      if {[string tolower [HTTP::uri]] == "/health-nsight-customer" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_nsight_customer
      set mypool $pool_nsight_customer
      set LogString "$LogString1 $mypool"
    }
    "/health-nsight-product-availability" -
    "/inventoryverification*" -
    "/locate*" -
    "/parts*" -
    "/v1/parts*" -
    "/v2/inventoryverification" -
    "/v2/parts*" {
      if {[string tolower [HTTP::uri]] == "/health-nsight-product-availability" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_nsight_product_availability
      set mypool $pool_nsight_product_availability
      set LogString "$LogString1 $mypool"
    }
    "/finditpartavailability*" -
    "/health-nsight-product-availability-b2b" -
    "/isscquery*" -
    "/multistorepartpriceavailability*" -
    "/partpriceavailability*" {
      if {[string tolower [HTTP::uri]] == "/health-nsight-product-availability-b2b" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_nsight_product_availability_b2b
      set mypool $pool_nsight_product_availability_b2b
      set LogString "$LogString1 $mypool"
    }
    "/actuator/health*" -
    "/health-maintenance" {
      if {[string tolower [HTTP::uri]] == "/health-maintenance" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_maintenance
      set mypool $pool_maintenance
      set LogString "$LogString1 $mypool"
    }
    "/health-triggerssh" -
    "/triggerssh" {
      if {[string tolower [HTTP::uri]] == "/health-triggerssh" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_triggerssh
      set mypool $pool_triggerssh
      set LogString "$LogString1 $mypool"
    }
  }
  #----------------END-pools----------------#
}
when LB_SELECTED {
      # Create Variable to Log Pool Member Chosen
      set LogString2 "to Pool Mbr [LB::server addr]"
      # Log Client IP, URL, and Pool Member Chosen
      log local0. "$LogString $LogString2"
}
when HTTP_RESPONSE {
  set uuid "None"
  set packet_uuid [HTTP::header values uniqueid]
  set packet_uuid_len [string length $packet_uuid]
  if { $packet_uuid_len > 0 } {
     set uuid [HTTP::header values uniqueid]
  }
  log local0. "VIP:[virtual name], HTTP_RESPONSE, UUID:$uuid, HTTP Code:[HTTP::status], Pool Member:[LB::server addr] Client IP:[IP::client_addr]:[TCP::client_port]"
}
