# ESB iRule to set correct pool based on URI
# https://devcentral.f5.com/articles/irules-101-04-switch
#
when HTTP_REQUEST { 
  set uuid "None"
  set packet_uuid [HTTP::header values uniqueid]
  set packet_uuid_len [string length $packet_uuid]
  if { $packet_uuid_len > 0 } {
     set uuid [HTTP::header values uniqueid]
  }
  set xfwd [IP::client_addr]
  set packet_xfwd [HTTP::header X-Forwarded-For]
  set packet_xfwd_len [string length $packet_xfwd]
  if { $packet_xfwd_len > 0 } {
     set xfwd [HTTP::header X-Forwarded-For]
  }  
  #----------------BEGIN pools--------------#
  set pool_customer_account "nfuse2.genpt.net_pool_19276"
  set pool_customer_registration "nfuse2.genpt.net_pool_19275"
  set pool_maintenance "nfuse2.genpt.net_pool_19999"
  set pool_site_region "nfuse2.genpt.net_pool_19277"
  set pool_locateproductWHI "nfuse2.genpt.net_pool_19278"
  set pool_shipment_path "nfuse2.genpt.net_pool_19265"
  set pool_OrderWHI "nfuse2.genpt.net_pool_19280"
  set pool_storePrice "nfuse2.genpt.net_pool_19281"
  set pool_Barcode "nfuse2.genpt.net_pool_19282"
  set pool_prolink_registration "nfuse2.genpt.net_pool_19284"
  set pool_pulseorderstatusnotification "nfuse2.genpt.net_pool_19285"
  set pool_entity_subscription "nfuse2.genpt.net_pool_19286"
  set pool_ReplayConfigurationManagement "nfuse2.genpt.net_pool_9077"
  set pool_ApplicationConfigurationPropertiesManagement "nfuse2.genpt.net_pool_9076"
  set pool_AswaConfig "nfuse2.genpt.net_pool_19288"
  set pool_nsight_site_attributes "nfuse2.genpt.net_pool_19279"
  set pool_nsight_location "nfuse2.genpt.net_pool_19279"
  set LogString1 "VIP:[virtual name], HTTP_REQUEST, UUID:$uuid, Client IP:[IP::client_addr], Real Client IP $xfwd:[TCP::client_port], Requested URL [HTTP::host][HTTP::uri], Pool "
  # Matches in each section below should be in Alphabetical order
  # to facilitate a structure/be identical from environment to environment
  switch -glob [string tolower [HTTP::uri]] {
    "/accountstatus/*" -
    "/health-customer-account" {
      if {[string tolower [HTTP::uri]] == "/health-customer-account" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_customer_account
      set mypool $pool_customer_account
      set LogString "$LogString1 $mypool"
    }
    "/customer/registration/*" -
    "/health-customer-registration" {
      if {[string tolower [HTTP::uri]] == "/health-customer-registration" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_customer_registration
      set mypool $pool_customer_registration
      set LogString "$LogString1 $mypool"
    }
    "/actuator/health*" -
    "/health-maintenance" {
      if {[string tolower [HTTP::uri]] == "/health-maintenance" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_maintenance
      set mypool $pool_maintenance
      set LogString "$LogString1 $mypool"
    }
    "/health-site-region" -
    "/siteregion/*" {
      if {[string tolower [HTTP::uri]] == "/health-site-region" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_site_region
      set mypool $pool_site_region
      set LogString "$LogString1 $mypool"
    }
    "/health-locateproductwhi" -
    "/locateproductwhi/*" {
      if {[string tolower [HTTP::uri]] == "/health-locateproductwhi" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_locateproductWHI
      set mypool $pool_locateproductWHI
      set LogString "$LogString1 $mypool"
    }
    "/health-shipment-path" -
    "/shipment/getpathdetails/*" {
      if {[string tolower [HTTP::uri]] == "/health-shipment-path" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_shipment_path
      set mypool $pool_shipment_path
      set LogString "$LogString1 $mypool"
    }
    "/health-orderwhi" -
    "/orderwhi/*" {
      if {[string tolower [HTTP::uri]] == "/health-orderwhi" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_OrderWHI
      set mypool $pool_OrderWHI
      set LogString "$LogString1 $mypool"
    }
    "/health-storeprice" -
    "/storeprice/*" {
      if {[string tolower [HTTP::uri]] == "/health-storeprice" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_storePrice
      set mypool $pool_storePrice
      set LogString "$LogString1 $mypool"
    }
    "/barcode/*" -
    "/health-barcode" {
      if {[string tolower [HTTP::uri]] == "/health-barcode" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_Barcode
      set mypool $pool_Barcode
      set LogString "$LogString1 $mypool"
    }
    "/health-prolink-registration" -
    "/prolink/registration/*" {
      if {[string tolower [HTTP::uri]] == "/health-prolink-registration" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_prolink_registration
      set mypool $pool_prolink_registration
      set LogString "$LogString1 $mypool"
    }
    "/health-pulseorderstatusnotification" -
    "/rpm/pulse/notification/orderstatus/v1/*" {
      if {[string tolower [HTTP::uri]] == "/health-pulseorderstatusnotification" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_pulseorderstatusnotification
      set mypool $pool_pulseorderstatusnotification
      set LogString "$LogString1 $mypool"
    }
    "/entity/subscription/*" -
    "/health-entity-subscription" -
    "/subscription/*" {
      if {[string tolower [HTTP::uri]] == "/health-entity-subscription" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_entity_subscription
      set mypool $pool_entity_subscription
      set LogString "$LogString1 $mypool"
    }
    "/health-replayconfigurationmanagement" -
    "/replayconfig/management/*" {
      if {[string tolower [HTTP::uri]] == "/health-replayconfigurationmanagement" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_ReplayConfigurationManagement
      set mypool $pool_ReplayConfigurationManagement
      set LogString "$LogString1 $mypool"
    }
    "/config/management/*" -
    "/health-applicationconfigurationpropertiesmanagement" {
      if {[string tolower [HTTP::uri]] == "/health-applicationconfigurationpropertiesmanagement" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_ApplicationConfigurationPropertiesManagement
      set mypool $pool_ApplicationConfigurationPropertiesManagement
      set LogString "$LogString1 $mypool"
    }
    "/aswaconfig/*" -
    "/health-aswaconfig" {
      if {[string tolower [HTTP::uri]] == "/health-aswaconfig" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_AswaConfig
      set mypool $pool_AswaConfig
      set LogString "$LogString1 $mypool"
    }
    "/health-nsight-site-attributes" -
    "/nsight/site/aliasname/*" {
      if {[string tolower [HTTP::uri]] == "/health-nsight-site-attributes" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_nsight_site_attributes
      set mypool $pool_nsight_site_attributes
      set LogString "$LogString1 $mypool"
    }
    "/health-nsight-location" -
    "/locations/*" {
      if {[string tolower [HTTP::uri]] == "/health-nsight-location" } {
        HTTP::uri "/actuator/health"
      }
      # If any of the above is in the URI use the below pool
      pool $pool_nsight_location
      set mypool $pool_nsight_location
      set LogString "$LogString1 $mypool"
    }
  }
  #----------------END-pools----------------#
}
when LB_SELECTED {
      # Create Variable to Log Pool Member Chosen
      set LogString2 "to Pool Mbr [LB::server addr]"
      # Log Client IP, URL, and Pool Member Chosen
      log local0. "$LogString $LogString2"
}
when HTTP_RESPONSE {
  set uuid "None"
  set packet_uuid [HTTP::header values uniqueid]
  set packet_uuid_len [string length $packet_uuid]
  if { $packet_uuid_len > 0 } {
     set uuid [HTTP::header values uniqueid]
  }
  log local0. "VIP:[virtual name], HTTP_RESPONSE, UUID:$uuid, HTTP Code:[HTTP::status], Pool Member:[LB::server addr] Client IP:[IP::client_addr]:[TCP::client_port]"
}
