# ESB iRule to set correct pool based on URI
# https://devcentral.f5.com/articles/irules-101-04-switch
# https://devcentral.f5.com/articles/irules-recipe-2-transparent-request-target-rewriting-21922
#
when HTTP_REQUEST { 
  set uuid "None"
  set packet_uuid [HTTP::header values uniqueid]
  set packet_uuid_len [string length $packet_uuid]
  if { $packet_uuid_len > 0 } {
     set uuid [HTTP::header values uniqueid]
  }
  set xfwd [IP::client_addr]
  set packet_xfwd [HTTP::header X-Forwarded-For]
  set packet_xfwd_len [string length $packet_xfwd]
  if { $packet_xfwd_len > 0 } {
     set xfwd [HTTP::header X-Forwarded-For]
  }
  # Change to VIP Name to DNS Name of the VIP
  set vip_name_1 "esbmsqa.genpt.net"
  set var_pool "_pool_"
  # None of the below variables pool and port variables need to
  # be updated in order to port this iRule to another ESB environemt
  # Any additon to the Port Variables should be in numerical order
  set pool_port_1  "10000"
  set pool_port_2  "10001"
  set pool_port_3  "10002"
  set pool_port_4  "10003"
  set pool_port_5a "19111"
  set pool_port_5b "19112"
  set pool_port_5c "19111_19112"
  set pool_port_6  "19113_19114"
  set pool_port_6b "19113"
  set pool_port_7  "19236"
  set pool_1 $vip_name_1$var_pool$pool_port_1
  set pool_2 $vip_name_1$var_pool$pool_port_2
  set pool_3 $vip_name_1$var_pool$pool_port_3
  set pool_4 $vip_name_1$var_pool$pool_port_4
  set pool_5 $vip_name_1$var_pool$pool_port_5c
  set pool_6 $vip_name_1$var_pool$pool_port_6
  set pool_6b $vip_name_1$var_pool$pool_port_6b
  set pool_7 $vip_name_1$var_pool$pool_port_7
  #
  # The F5 is case sensitive so ALL matches should be lower case to avoide issues with case.
  # The matching code makes the URI variable, but the actual URI lower case, so the matching
  # string needs to be lowercase regardless of what case the Actual URI is.  The actual URI's
  # sent to the pool members in the case entered in the client's browser.
  #
  # Matches in each section below should be in Alphebetical order
  # to facilite a structure/be identical from environment to environment
  #  
  switch -glob [string tolower [HTTP::uri]] {
    "/invoice/invoicemessage*" -  
    "/invoice/storenum*" -
    "/v1/invoice*" -
    "/v2/invoice*" {
    # Above matches in each section should be in Alphebetical order
    # If any of the above is in the URI use the below pool
      pool $pool_1
      set mypool $pool_1
      set LogString "VIP:[virtual name], HTTP_REQUEST, UUID:$uuid, Client IP:[IP::client_addr], Real Client IP $xfwd:[TCP::client_port], Requested URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
    "/10000*" {
    # iRule ReWrite for Port
      set replaceField "/$pool_port_1"
      set uri [HTTP::uri]
      set newUri "/[ string trimleft $uri $replaceField ]"
      HTTP::path $newUri
      pool $pool_1
      set mypool $pool_1
      set LogString "VIP:[virtual name] Real Client IP [HTTP::header X-Forwarded-For]:[TCP::client_port] Requested URL [HTTP::host]$uri New URL [HTTP::host]$newUri Pool $mypool"
    }    
    "/getinvoice*" {
    # Above matches in each section should be in Alphebetical order
    # If any of the above is in the URI use the below pool
      pool $pool_2
      set mypool $pool_2
      set LogString "VIP:[virtual name], HTTP_REQUEST, UUID:$uuid, Client IP:[IP::client_addr], Real Client IP $xfwd:[TCP::client_port], Requested URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
    "/10001*" {
    # iRule ReWrite for Port
      set replaceField "/$pool_port_2"
      set uri [HTTP::uri]
      set newUri "/[ string trimleft $uri $replaceField ]"
      HTTP::path $newUri
      pool $pool_2
      set mypool $pool_2
      set LogString "VIP:[virtual name] Real Client IP [HTTP::header X-Forwarded-For]:[TCP::client_port] Requested URL [HTTP::host]$uri New URL [HTTP::host]$newUri Pool $mypool"
    }      
    "/customer*" {
    # Above matches in each section should be in Alphebetical order
    # If any of the above is in the URI use the below pool
      pool $pool_3
      set mypool $pool_3
      set LogString "VIP:[virtual name], HTTP_REQUEST, UUID:$uuid, Client IP:[IP::client_addr], Real Client IP $xfwd:[TCP::client_port], Requested URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
    "/10002*" {
    # iRule ReWrite for Port
      set replaceField "/$pool_port_3"
      set uri [HTTP::uri]
      set newUri "/[ string trimleft $uri $replaceField ]"
      HTTP::path $newUri
      pool $pool_3
      set mypool $pool_3
      set LogString "VIP:[virtual name] Real Client IP [HTTP::header X-Forwarded-For]:[TCP::client_port] Requested URL [HTTP::host]$uri New URL [HTTP::host]$newUri Pool $mypool"
    }      
    "/order*" -
    "/rules*" {
    # Above matches in each section should be in Alphebetical order
    # If any of the above is in the URI use the below pool
      pool $pool_4
      set mypool $pool_4
      set LogString "VIP:[virtual name], HTTP_REQUEST, UUID:$uuid, Client IP:[IP::client_addr], Real Client IP $xfwd:[TCP::client_port], Requested URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
    "/10003*" {
    # iRule ReWrite for Port
      set replaceField "/$pool_port_4"
      set uri [HTTP::uri]
      set newUri "/[ string trimleft $uri $replaceField ]"
      HTTP::path $newUri
      pool $pool_4
      set mypool $pool_4
      set LogString "VIP:[virtual name] Real Client IP [HTTP::header X-Forwarded-For]:[TCP::client_port] Requested URL [HTTP::host]$uri New URL [HTTP::host]$newUri Pool $mypool"
    }     
    "/inventoryverification*" -
    "/parts*" -
    "/v1/parts*" -
    "/v2/parts*" {
    # Above matches in each section should be in Alphebetical order
    # If any of the above is in the URI use the below pool
      pool $pool_5
      set mypool $pool_5
      set LogString "VIP:[virtual name], HTTP_REQUEST, UUID:$uuid, Client IP:[IP::client_addr], Real Client IP $xfwd:[TCP::client_port], Requested URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
	"/v2/inventoryverification" {
    # Above matches in each section should be in Alphebetical order
    # If any of the above is in the URI use the below pool
      pool $pool_5
      set mypool $pool_5
      set LogString "VIP:[virtual name], HTTP_REQUEST, UUID:$uuid, Client IP:[IP::client_addr], Real Client IP $xfwd:[TCP::client_port], Requested URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
    "/19111*" {
    # iRule ReWrite for Port
      set poolPort "19111"
      set replaceField "/$poolPort"
      set uri [HTTP::uri]
      set newUri "/[ string trimleft $uri $replaceField ]"
      HTTP::path $newUri
      pool $pool_5
      set mypool $pool_5
      set LogString "VIP:[virtual name] Real Client IP [HTTP::header X-Forwarded-For]:[TCP::client_port] Requested URL [HTTP::host]$uri New URL [HTTP::host]$newUri Pool $mypool"
    }
    "/19112*" {
    # iRule ReWrite for Port    
      set poolPort "19112"
      set replaceField "/$poolPort"
      set uri [HTTP::uri]
      set newUri "/[ string trimleft $uri $replaceField ]"
      HTTP::path $newUri
      pool $pool_5
      set mypool $pool_5
      set LogString "VIP:[virtual name] Real Client IP [HTTP::header X-Forwarded-For]:[TCP::client_port] Requested URL [HTTP::host]$uri New URL [HTTP::host]$newUri Pool $mypool"
    }      
	"/finditpartavailability*" -
	"/isscquery/v1*" -
	"/multistorepartpriceavailability*" -
	"/partpriceavailability*"	{
    # Above matches in each section should be in Alphebetical order
    # If any of the above is in the URI use the below pool
      pool $pool_6
      set mypool $pool_6
      set LogString "VIP:[virtual name], HTTP_REQUEST, UUID:$uuid, Client IP:[IP::client_addr], Real Client IP $xfwd:[TCP::client_port], Requested URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
    "/isscquery*" {
    # Above matches in each section should be in Alphebetical order
    # If any of the above is in the URI use the below pool
      pool $pool_6b
      set mypool $pool_6b
      set LogString "VIP:[virtual name], HTTP_REQUEST, UUID:$uuid, Client IP:[IP::client_addr], Real Client IP $xfwd:[TCP::client_port], Requested URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
    "/19113*" {
    # iRule ReWrite for Port
      set replaceField "/$pool_port_6"
      set uri [HTTP::uri]
      set newUri "/[ string trimleft $uri $replaceField ]"
      HTTP::path $newUri
      pool $pool_6
      set mypool $pool_6
      set LogString "VIP:[virtual name] Real Client IP [HTTP::header X-Forwarded-For]:[TCP::client_port] Requested URL [HTTP::host]$uri New URL [HTTP::host]$newUri Pool $mypool"
    }
    "/isscorder*" {
    # Above matches in each section should be in Alphebetical order
    # If any of the above is in the URI use the below pool
      pool $pool_7
      set mypool $pool_7
      set LogString "VIP:[virtual name], HTTP_REQUEST, UUID:$uuid, Client IP:[IP::client_addr], Real Client IP $xfwd:[TCP::client_port], Requested URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
    "/19236*" {
    # iRule ReWrite for Port
      set replaceField "/$pool_port_7"
      set uri [HTTP::uri]
      set newUri "/[ string trimleft $uri $replaceField ]"
      HTTP::path $newUri
      pool $pool_7
      set mypool $pool_7
      set LogString "VIP:[virtual name] Real Client IP [HTTP::header X-Forwarded-For]:[TCP::client_port] Requested URL [HTTP::host]$uri New URL [HTTP::host]$newUri Pool $mypool"
    }
  }
}
when LB_SELECTED {
      # Create Variable to Log Pool Member Chosen
      set LogString2 "to Pool Mbr [LB::server addr]"
      # Log Client IP, URL, and Pool Member Chosen
      log local0. "$LogString $LogString2"
}
when HTTP_RESPONSE {
  set uuid "None"
  set packet_uuid [HTTP::header values uniqueid]
  set packet_uuid_len [string length $packet_uuid]
  if { $packet_uuid_len > 0 } {
     set uuid [HTTP::header values uniqueid]
  }
  log local0. "VIP:[virtual name], HTTP_RESPONSE, UUID:$uuid, HTTP Code:[HTTP::status], Pool Member:[LB::server addr] Client IP:[IP::client_addr]:[TCP::client_port]"
}