# ESB iRule to set correct pool based on URI
# https://devcentral.f5.com/articles/irules-101-04-switch
#
when HTTP_REQUEST { 
  set uuid "None"
  set packet_uuid [HTTP::header values uniqueid]
  set packet_uuid_len [string length $packet_uuid]
  if { $packet_uuid_len > 0 } {
     set uuid [HTTP::header values uniqueid]
  }
  set xfwd [IP::client_addr]
  set packet_xfwd [HTTP::header X-Forwarded-For]
  set packet_xfwd_len [string length $packet_xfwd]
  if { $packet_xfwd_len > 0 } {
     set xfwd [HTTP::header X-Forwarded-For]
  }
  # Change to VIP Name to DNS Name of the VIP
  set vip_name_1 "esbuat.genpt.net"
  # None of the below variables pool and port variables need to 
  # be updated in order to port this iRule to another ESB environemt  
  set pool_port_1 "_pool_9222"
  set pool_port_2 "_pool_9242"
  set pool_port_3 "_pool_9262"
  set pool_port_4 "_pool_9282"
  set pool_port_5 "_pool_9302"
  set pool_port_6 "_pool_9322"
  set pool_1 $vip_name_1$pool_port_1
  set pool_2 $vip_name_1$pool_port_2
  set pool_3 $vip_name_1$pool_port_3
  set pool_4 $vip_name_1$pool_port_4
  set pool_5 $vip_name_1$pool_port_5
  set pool_6 $vip_name_1$pool_port_6
  # Matches in each section below should be in Alphebetical order
  # to facilite a structure/be identical from environment to environment
  switch -glob [string tolower [HTTP::uri]] {
    "/addshiptoaddress*" -
    "/associateusertoaccount*" -
    "/createcontactperson*" -
    "/createcustomer*" -
    "/deliverystatus*" -
    "/directpartissue/directpartissueservice*" -
    "/ejoieservices/ejoiewebservices*" -
    "/getbillinglist*" -
    "/getbillingpdf*" -
    "/getdeliverylist*" -
    "/getnewibsstores*" -
    "/getorderlist*" -
    "/getorderpdf*" -
    "/getpricing*" -
    "/getquotelist*" -
    "/inventorylookup*" -
    "/ordersubmit*" -
    "/ordersubmit_v2*" -
    "/parttransfer/parttransferservice*" -
    "/ping*" -
    "/updatecontactperson*" -
    "/updateshiptoaddress*" -
    "/validateaccount*" -
    "/workorderservice/workorderrequest*" {
    # Above matches in each section should be in Alphebetical order
    # If any of the above is in the URI use the below pool
      pool $pool_1
      set mypool $pool_1
      set LogString "VIP:[virtual name], HTTP_REQUEST, UUID:$uuid, Client IP:[IP::client_addr], Real Client IP $xfwd:[TCP::client_port], Requested URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
    "/activantaconnex/activantaconnexservice*" -
    "/b2binvoiceinquiry*" -
    "/cfa_posreconciliation/cfaposreconciliationservice*" -
    "/fms-b2bpartorder*" -
    "/ibiz_posreconciliation*" -
    "/lucity/pos/lucityposservice*" -
    "/oakridgeposreconciliation/posreconciliationservice*" -
    "/partissue/partissueservice*" -
    "/partupdaterequest/partupdaterequestservice*" -
    "/ping*" -
    "/posreconciliation/posreconciliationservice*" -
    "/postransaction/postransactionservice*" -
    "/prolinkregistration*" -
    "/sanimax/pos/sanimaxposservice*" -
    "/sc_posdata/scposdataservice*" -
    "/southwestposreconciliation/posreconciliationservice*" -
    "/stjohnposreconciliation/stjohnposdataservice*" -
    "/validateaddress*" -
    "/xeroxposreconciliation/posreconciliationservice*" {
    # Above matches in each section should be in Alphebetical order
    # If any of the above is in the URI use the below pool
      pool $pool_2
      set mypool $pool_2
      set LogString "VIP:[virtual name], HTTP_REQUEST, UUID:$uuid, Client IP:[IP::client_addr], Real Client IP $xfwd:[TCP::client_port], Requested URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
    "/checkstorenumber*" -
    "/checkstorenumber/v2*" -
    "/checkstorenumber_v2*" -
    "/ejoei-jdesalesorder*" -
    "/ejoei-orderstatus*" -
    "/eplanogram*" -
    "/getstoredata*" -
    "/ijoei-jdemultipartinq*" -
    "/loyalty-claimpoints*" -
    "/loyalty-locationstatus*" -
    "/loyalty-memberactivity*" -
    "/loyalty-memberstatus*" -
    "/loyalty-pendingreward*" -
    "/loyalty-registration*" -
    "/loyalty-transactions*" -
    "/micorservice/micorservice*" -
    "/nol-b2bpartinq*" -
    "/nol-b2bsalesorder*" -
    "/nol-ca-b2bpartinq*" -
    "/nol-ca-b2bsalesorder*" -
    "/nol-salesorder*" -
    "/ping*" -
    "/portalnotify*" -
    "/storeipservices*" -
    "/tams-loyalty-memberstatus*" -
    "/tams-loyalty-registration*" -
    "/returnnotification*" -
    "/tams-loyalty-transactions*" -
    "/validatepayment*" {
    # Above matches in each section should be in Alphebetical order
    # If any of the above is in the URI use the below pool
      pool $pool_3
      set mypool $pool_3
      set LogString "VIP:[virtual name], HTTP_REQUEST, UUID:$uuid, Client IP:[IP::client_addr], Real Client IP $xfwd:[TCP::client_port], Requested URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
    "/aggregateinvoiceinquiry*" -
    "/dcinventory*" -
    "/deliveryexception*" -
    "/getcustomerprofile*" -
    "/getproductavailability*" -
    "/getshuttlefeed*" -
    "/getsiterelationship*" -
    "/inventorylinefeed*" -
    "/inventorypartdetail*" -
    "/inventorystocklocation*" -
    "/inventorysync*" -
    "/inventorysyncstatus*" -
    "/ping*" -
    "/rest/validateaddress*" -
    "/retrieveorder*" -
    "/rpminventorysyncstatus*" -
    "/rpminventoryverification*" -
    "/returnnotification*" -
    "/sitedelivery*" -
    "/sitedeliveryfeed*" -
    "/sitefeed*" -
    "/siterelationship*" -
    "/sitetositedeliveryfeed*" -
    "/storeconsolefeed*" -
    "/storeinventory*" -
    "/storeinvoicelkp*" -
    "/supplierinventory*" -
    "/supplierinventoryrefresh*" -
    "/v1/tokenization/custtokenlookup*" -
    "/v1/tokenmanagement*" -
    "/v2/tokenmanagement*" {
    # Above matches in each section should be in Alphebetical order
    # If any of the above is in the URI use the below pool
      pool $pool_4
      set mypool $pool_4
      set LogString "VIP:[virtual name], HTTP_REQUEST, UUID:$uuid, Client IP:[IP::client_addr], Real Client IP $xfwd:[TCP::client_port], Requested URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
    "/asn*" -
    "/cart*" -
    "/getshippingquote*" -
    "/getuomconversion*" -
    "/invoice*" -
    "/optimizecart*" -
    "/order*" -
    "/partsaggbysiterelationship*" -
    "/ping*" -
    "/receiveinvoicefeed*" -
    "/receivenotification*" -    
    "/requestforquote*" -
    "/submitorder*" -
    "/v1/partsaggbysiterelationship*" -
    "/v1/partsavailabilitydetails*" -
    "/v1/partsavailability*" -
    "/v2/partsavailability*" -
    "/v2/partsavailabilitydetails*" {
    # Above matches in each section should be in Alphebetical order
    # If any of the above is in the URI use the below pool
      pool $pool_5
      set mypool $pool_5
      set LogString "VIP:[virtual name], HTTP_REQUEST, UUID:$uuid, Client IP:[IP::client_addr], Real Client IP $xfwd:[TCP::client_port], Requested URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
    "/cancelorder*" -
    "/cardpayment*" -
    "/ejoei-jdesalesorder*" -
    "/ejoei-orderstatus*" -
    "/ijoei-jdemultipartinq*" -
    "/nol-b2bsalesorder*" -
    "/nol-ca-b2bpartinq*" -
    "/nxporderstatusnotification*" -
    "/v1/partsaggbysiterelationship*" {
    # Above matches in each section should be in Alphebetical order
    # If any of the above is in the URI use the below pool
      pool $pool_6
      set mypool $pool_6
      set LogString "VIP:[virtual name], HTTP_REQUEST, UUID:$uuid, Client IP:[IP::client_addr], Real Client IP $xfwd:[TCP::client_port], Requested URL [HTTP::host][HTTP::uri], Pool $mypool"
    }
  }
}

when LB_SELECTED {
      # Create Variable to Log Pool Member Chosen
      set LogString2 "to Pool Mbr [LB::server addr]"
      # Log Client IP, URL, and Pool Member Chosen
      log local0. "$LogString $LogString2"
}
when HTTP_RESPONSE {
  set uuid "None"
  set packet_uuid [HTTP::header values uniqueid]
  set packet_uuid_len [string length $packet_uuid]
  if { $packet_uuid_len > 0 } {
     set uuid [HTTP::header values uniqueid]
  }
  log local0. "VIP:[virtual name], HTTP_RESPONSE, UUID:$uuid, HTTP Code:[HTTP::status], Pool Member:[LB::server addr] Client IP:[IP::client_addr]:[TCP::client_port]"
}